Contact Us | Arxan
Description: Contact Arxan Technologies.

# Contact Us

## Office Locations and Contact Details

Headquarters

- 6903 Rockledge Drive, Suite 1250
  Bethesda, MD 20817
  Phone: (301) 968-4290
  Fax: (301) 968-4291

Europe

- London
  20-22 Bedford Row
  London, UK WC1R 4JS
  Phone: +44 17533 71691

- France
  Phone: +33 670 160 962

  Germany
  Phone: +49 177 4410002

  Sweden
  Phone: +46 70 3001107

R&D Centers

- San Francisco
  575 Market Street, Suite 2450
  San Francisco, CA 94105
  Phone: (301) 968-4290
  Fax: (415) 247-0910
- West Lafayette
  1305 Cumberland Ave Ste 215
  West Lafayette, IN 47906
  Phone: (765) 889-4756

Japan

- Shinagawa Intercity Tower A, 28th floor
  2-15-1 Konan, Minato-ku, Tokyo
  Phone: +81.90.1459.5878

- Arxan provides the world’s strongest application protection solutions.

  Our unique patented guarding technology

  1. Defends applications against attacks

  2. Detects when an attack is being attempted, and

  3. Responds to detected attacks with alerts and repairs.

  Arxan offers solutions for software running on mobile devices, desktops, servers, and embedded platforms – including those connected as part of the Internet of Things (IOT) – and is currently protecting applications running on more than 500 million devices across a range of industries.

- ### Industry Solutions

- © 2015 Arxan Technologies, Inc. All Rights Reserved.

- Terms of Use | Privacy Policy | Site Map